package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````H)D$"#0```!@L@```````#0`(``(
M`"@`&P`:``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(\*@`
M`/"H```%`````!````$````$KP``!#\%"`0_!0A4`@``G!(```8`````$```
M`@```!BO```8/P4(&#\%"-@```#8````!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%'E=&0```````````````````````````8`
M```$````4N5T9`2O```$/P4(!#\%"/P```#\````!`````$````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````/````
M!````!0````#````1TY5``I8\,8T"0;H->$!\?_.O^*>AK%4)0```%`````(
M````"``````0$`0E0`2`J`$``:*&`:A````"3R@$*3BB,D>*A`P(4````%(`
M``````````````````!4````5@```%<```!8````60```%H`````````6P``
M`%T```!>`````````%\```````````````````!@````8P``````````````
M9````&8```!G````:0````````!K````;0``````````````;P```'````!R
M`````````,C5LG%9Z.WLSMY'+:/@^TGJT^\.I]VC:R_%F[;;S>.>Y^]?>X?Y
MG(%K"4/6##J7"T>8!<;%B060#13BGB'_Y`ZR`8MOQ+F<0&M_FGQ_J9R;;L7?
M']EQ6!R[XY)\U&34?*U+X\`R8MOMX:<""F:OS&9[\$IKXD?&`4-%U>Q]08[%
MPN4_+*$B"R#RV],=^J%L8+F-\0X`````````````````````Z@(`````````
M````$@```+$``````````````!(```!X`P`````````````2````8P,`````
M````````$@```*$!`````````````!(```"H`P`````````````2````>@(`
M````````````$@```!$``````````````"`````@```````````````@````
M:0,`````````````$@```(T!`````````````!(```#)`P`````````````2
M````;@$`````````````$@```(`!`````````````!(````%!```````````
M```2````&@,`````````````$@```,D"`````````````!(````L`@``````
M```````2````_0``````````````$@```!P"`````````````!(```"-`P``
M```````````2````R@$`````````````$@```#H$`````````````!(```#X
M`P`````````````2````U@(`````````````$@```-$"`````````````!(`
M``"8`@`````````````2````Z@$`````````````$@```*8!````````````
M`!(````U`@`````````````2````M@,`````````````$@```"P$````````
M`````!(````O`0`````````````2````P0,`````````````$@```#0`````
M`````````!(```#3`P`````````````2````70$`````````````$@```,@`
M`````````````!(````,!``````````````2````H0,`````````````$@``
M`/$#`````````````!(```"&`P`````````````2````7`,`````````````
M$@```/L$`````````````!(```!!`0`````````````2````X0,`````````
M````$@```%P"`````````````!(```!"`P`````````````2````^P(`````
M````````$@```$X"`````````````!(```"4`P`````````````2````D0(`
M````````````$@```*L!`````````````!(```!+`P`````````````2````
MFP,`````````````$@```'\#`````````````!(```#L```````````````2
M````0@``````````````$@```.@#`````````````!(````D!```````````
M```2````UP``````````````$@```/X!`````````````!(```"%`@``````
M```````2````4`$`````````````$@```!8$`````````````!(```!Q`P``
M```````````2````,0,`````````````$@```,("`````````````!(````=
M`0`````````````2````0P(`````````````$@```%0``````````````!(`
M``#8`0`````````````2````8P``````````````$@```#,$````````````
M`!(```"/```````````````2````.0,`````````````$@```"P#````````
M`````!(```!X```````````````2````"P$`````````````$@```+<!````
ME00(`````!(```"<!```0,H$"`0````1``\`>04``)"W!`@-"@``$@`-`*4%
M``"0M`0(E0$``!(`#0"6!```#,H$"``````2``X`3@0``&!!!0@$````(0`8
M`&X$``!PL00(#````!(`#0`E!0``<,D$"%H````2``T`.@4```#-!`CJ6P``
M$0`/`*````#@E@0(`````!(````0!0``1$$%"``````0`!<`$@4``$1!!0@`
M````(``7`#4%``!0004(!````!$`%P!-!```8$$%"`0````A`!@`C`0``-#)
M!`@%````$@`-`)@%``"`L00(Z0$``!(`#0"Y!```,+8$"$`````2``T`3`0`
M`&!!!0@$````$0`8`$<$```0QP0((`(``!(`#0#I!```<+8$"!\````2``T`
M!`4``##&!`AU````$@`-`%T$``!8004(`````!``\?]I!```H%$%"``````0
M`/'_HP0``*#!!`B,!```$@`-``L#``!$R@0(!````!$`#P`6!0``H)D$"```
M```2``T`QP0``*"P!`C$````$@`-`-T$``"@LP0([````!(`#0!J`@``T)8$
M"``````2````?P0``'"S!`@B````$@`-`%8$``!8004(`````!``\?])!0``
ML,8$"%P````2``T`'04``/"O!`@^````$@`-`&4%``!4004(!````!$`%P"C
M`@``9$$%"!,````1`!@`A@4``)"V!`CT````$@`-`!\%``!0E`0(`````!(`
M"P``;&EB<&5R;"YS;RXU+C$P`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E
M<D-L87-S97,`4&5R;%]S>7-?=&5R;0!097)L7TES=&%T8G5F7W!T<@!097)L
M7W-Y<U]I;FET,P!097)L7TEE>&ET7V9L86=S7W!T<@!097)L7W-A=F5?9&5S
M=')U8W1O<E]X`%!E<FQ?26-O;7!C=E]P='(`4&5R;%]A=&9O<FM?;&]C:P!0
M97)L7TEC=7)S=&%C:VEN9F]?<'1R`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%!E<FQ?27!A<G-E<E]P='(`4&5R;%]A=E]S:&EF=`!0
M97)L7W-V7S)P=E]F;&%G<P!097)L7TET;W!?96YV7W!T<@!097)L7TET86EN
M=&5D7W!T<@!097)L7W-V7W-E='!V;@!097)L7VYE=U-6<'8`4&5R;%]N97=8
M4U]F;&%G<P!097)L7TEI;E]E=F%L7W!T<@!097)L7TEO<%]P='(`4&5R;%])
M979A;%]R;V]T7W!T<@!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]'=&AR7VME>5]P='(`4&5R
M;%]'9&]?=6YD=6UP7W!T<@!097)L7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T
M<@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]D;W5N=VEN9`!097)L
M7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!03%]M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``;W!E;C8T`&QS965K
M-C0`<F5A9`!P=&AR96%D7V=E='-P96-I9FEC`%]?97)R;F]?;&]C871I;VX`
M8VQO<V4`;&EB8RYS;RXV`%])3U]S=&1I;E]U<V5D`%]?<F5G:7-T97)?871F
M;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P>0!?7W-T<FYC
M<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`7U]C='EP95]B
M7VQO8P!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C
M:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R
M8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?961A=&$`7U]B<W-?
M<W1A<G0`7V5N9`!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI
M8F-?8W-U7V9I;FD`7V9P7VAW`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?
M96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?7V1A=&%?
M<W1A<G0`>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`;F%M95]L;V%D7VUY7W!A
M<E]P;`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<VEZ95]L;V%D7VUY
M7W!A<E]P;`!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I
M;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS`$=,24)#
M7S(N,RXR`$=,24)#7S(N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C`````"````
M`P`#````!``````````#````!0```````P`&``<``````````P````,`!``"
M``(```````,````%``,````#````"```````!0`#``,``P`#``,````#````
M`P`"`````P`#````"0`#``,```````,``P````````````0``P`#``<`````
M``````````,````#``,``````````0`!``$``0`#``$``0`!`````0`!``$`
M`P`!``$``0`#``$``0`!``$``0`!``$``0`!``$````!``$``0`!``$````!
M``$``0`&``$#```0````<````!1I:0T```D`L@4``!`````3:6D-```(`+P%
M```0````<AEI"0``!@#&!0``$````!)I:0T```4`T@4``!````!T&6D)```$
M`-P%```0````$&EI#0```P#H!0````````$``@"R`@``$``````````2:6D-
M```'`-(%```0````$&EI#0```@#H!0```````/`_!0@&"```8$$%"`5A``!D
M004(!7(```!`!0@'`0``!$`%"`<"```(0`4(!P,```Q`!0@'!```$$`%"`<%
M```40`4(!P8``!A`!0@'!P``'$`%"`=0```@0`4(!P@``"1`!0@'"@``*$`%
M"`<+```L0`4(!PP``#!`!0@'#0``-$`%"`<.```X0`4(!P\``#Q`!0@'$```
M0$`%"`<1``!$0`4(!Q(``$A`!0@'$P``3$`%"`<4``!00`4(!Q4``%1`!0@'
M%@``6$`%"`<7``!<0`4(!Q@``&!`!0@'&0``9$`%"`<:``!H0`4(!QL``&Q`
M!0@''```<$`%"`<=``!T0`4(!QX``'A`!0@''P``?$`%"`<@``"`0`4(!R$`
M`(1`!0@'(@``B$`%"`<C``",0`4(!R0``)!`!0@';```E$`%"`=9``"80`4(
M!R4``)Q`!0@')@``H$`%"`<G``"D0`4(!R@``*A`!0@'*0``K$`%"`<J``"P
M0`4(!RL``+1`!0@'+```N$`%"`<M``"\0`4(!RX``,!`!0@'+P``Q$`%"`<P
M``#(0`4(!S$``,Q`!0@',@``T$`%"`<S``#40`4(!S0``-A`!0@'-0``W$`%
M"`<V``#@0`4(!S<``.1`!0@'.```Z$`%"`<Y``#L0`4(!SH``/!`!0@'.P``
M]$`%"`<\``#X0`4(!ST``/Q`!0@'/@```$$%"`<_```$004(!T````A!!0@'
M00``#$$%"`="```0004(!T,``!1!!0@'1```&$$%"`=%```<004(!T8``"!!
M!0@'1P``)$$%"`=(```H004(!TD``"Q!!0@'2@``,$$%"`=+```T004(!TP`
M`#A!!0@'30``/$$%"`=.``!`004(!T\``%6)Y5.#[`3H`````%N!PYBK``"+
MD_S___^%TG0%Z)X```#HN04``.AD-0``6%O)P_\U^#\%"/\E_#\%"`````#_
M)0!`!0AH`````.G@_____R4$0`4(:`@```#IT/____\E"$`%"&@0````Z<#_
M____)0Q`!0AH&````.FP_____R400`4(:"````#IH/____\E%$`%"&@H````
MZ9#_____)1A`!0AH,````.F`_____R4<0`4(:#@```#I</____\E($`%"&A`
M````Z6#_____)21`!0AH2````.E0_____R4H0`4(:%````#I0/____\E+$`%
M"&A8````Z3#_____)3!`!0AH8````.D@_____R4T0`4(:&@```#I$/____\E
M.$`%"&AP````Z0#_____)3Q`!0AH>````.GP_O___R5`0`4(:(````#IX/[_
M__\E1$`%"&B(````Z=#^____)4A`!0AHD````.G`_O___R5,0`4(:)@```#I
ML/[___\E4$`%"&B@````Z:#^____)51`!0AHJ````.F0_O___R580`4(:+``
M``#I@/[___\E7$`%"&BX````Z7#^____)6!`!0AHP````.E@_O___R5D0`4(
M:,@```#I4/[___\E:$`%"&C0````Z4#^____)6Q`!0AHV````.DP_O___R5P
M0`4(:.````#I(/[___\E=$`%"&CH````Z1#^____)7A`!0AH\````.D`_O__
M_R5\0`4(:/@```#I\/W___\E@$`%"&@``0``Z>#]____)81`!0AH"`$``.G0
M_?___R6(0`4(:!`!``#IP/W___\EC$`%"&@8`0``Z;#]____)9!`!0AH(`$`
M`.F@_?___R640`4(:"@!``#ID/W___\EF$`%"&@P`0``Z8#]____)9Q`!0AH
M.`$``.EP_?___R6@0`4(:$`!``#I8/W___\EI$`%"&A(`0``Z5#]____):A`
M!0AH4`$``.E`_?___R6L0`4(:%@!``#I,/W___\EL$`%"&A@`0``Z2#]____
M);1`!0AH:`$``.D0_?___R6X0`4(:'`!``#I`/W___\EO$`%"&AX`0``Z?#\
M____)<!`!0AH@`$``.G@_/___R7$0`4(:(@!``#IT/S___\ER$`%"&B0`0``
MZ<#\____)<Q`!0AHF`$``.FP_/___R700`4(:*`!``#IH/S___\EU$`%"&BH
M`0``Z9#\____)=A`!0AHL`$``.F`_/___R7<0`4(:+@!``#I</S___\EX$`%
M"&C``0``Z6#\____)>1`!0AHR`$``.E0_/___R7H0`4(:-`!``#I0/S___\E
M[$`%"&C8`0``Z3#\____)?!`!0AHX`$``.D@_/___R7T0`4(:.@!``#I$/S_
M__\E^$`%"&CP`0``Z0#\____)?Q`!0AH^`$``.GP^____R4`004(:``"``#I
MX/O___\E!$$%"&@(`@``Z=#[____)0A!!0AH$`(``.G`^____R4,004(:!@"
M``#IL/O___\E$$$%"&@@`@``Z:#[____)11!!0AH*`(``.F0^____R48004(
M:#`"``#I@/O___\E'$$%"&@X`@``Z7#[____)2!!!0AH0`(``.E@^____R4D
M004(:$@"``#I4/O___\E*$$%"&A0`@``Z4#[____)2Q!!0AH6`(``.DP^___
M_R4P004(:&`"``#I(/O___\E-$$%"&AH`@``Z1#[____)3A!!0AH<`(``.D`
M^____R4\004(:'@"``#I\/K___\E0$$%"&B``@``Z>#Z__\Q[5Z)X8/D\%!4
M4FC0R00(:'#)!`A15F@0QP0(Z"_\___TD)"0D)"0D)"0D)"0D)!5B>53@^P$
M@#UX004(`'4_H7Q!!0B[$#\%"('K##\%",'[`H/K`3G8<QZ-M@````"#P`&C
M?$$%"/\4A0P_!0BA?$$%"#G8<NC&!7A!!0@!@\0$6UW#C70F`(V\)P````!5
MB>6#[!BA%#\%"(7`=!*X`````(7`=`G'!"04/P4(_]#)PY"0D)"0D)"0D)"0
MD)!5B<&)Y8/!'%=64X'L8`$``(F%K/[__S'`C;0F`````(L4@0_*B92%M/[_
M_X/``8/X$'7LC97H_O__C4WHC78`BT+L,P(S0M0S0LS!R!^)0@R#P@0YRG7H
MBY6L_O__BX6L_O__B[6L_O__BXVL_O__BU($BP"+=A"+20B)E:3^__^+E;3^
M__^+G:S^__^)A:C^___!P`6)C:#^__^+O:#^__\!\HV,`IEY@EJ+A:3^__^+
M6PR+E:#^__\CE:3^___WT"'8"="+E;C^__\!P8N%J/[__XFUF/[__XNUI/[_
M_XF=G/[__P':BYVH_O__]]`CA:#^___!QAXA\PG8BYVH_O__C90"F7F"6HG(
MP<`%`<(#O;S^__^)T,'`!<'#'HV$!YEY@EJ)SXF%E/[__XG((=_WT"'P`[7`
M_O__"?@#A93^__^)U\'!'HFUE/[__XG6(<_WUB'>"?Z+O93^__\#G<3^___!
MPAZ-M#>9>8):B;6P_O__B<;!Q@4#M;#^__^)]\''!8V\.YEY@EJ)PXF]E/[_
M__?3B<<AUR'+"?N)]P.=E/[__P.-R/[__\'`'B''B8V4_O__B?'WT2'1"?F+
MO93^__\#E<S^___!QAZ-C`^9>8):B8VP_O__B=G!P04#C;#^__^)S\''!8V\
M.IEY@EJ)VO?2(<(#A=#^__^)O93^__^)WR'W"?J)SP.5E/[__XF%E/[__XG(
MP<,>]]`AWR'P"?B+O93^__\#M=3^___!P1Z-A`>9>8):B86P_O__B[VP_O__
MB=#!P`4!QXGXP<`%C80&F7F"6HG6B864_O__B=`ASO?0(=@#G=C^__\)\`.%
ME/[__XG^P<(>B9V4_O__B?LAUO?3(<L)\XNUE/[__P.-W/[__\'''HV<'IEY
M@EJ)G;#^__^)P\'#!0.=L/[__XG>P<8%C;0QF7F"6HG!]]$AT0.5X/[__XFU
ME/[__XG&(?X)\8G>`XV4_O__B964_O__B=K!P![WTB'&(?H)\HNUE/[__P.]
MY/[__\'#'HV4%IEY@EJ)E;#^__^+M;#^__^)RL'"!0'6B?+!P@6-E!>9>8):
MB<^)E93^__^)RB'?]](AP@.%Z/[__PGZ`Y64_O__B??!P1Z)A93^__^)\"'/
M]]`AV`GXB[V4_O__`YWL_O__P<8>C80'F7F"6HF%L/[__XN]L/[__XG0P<`%
M`<>)^,'`!8V$`YEY@EJ)TXF%E/[__XG0(?/WT"'(`XWP_O__"=@#A93^__^)
M^\'"'HF-E/[__XGY(=/WT2'Q"=F+G93^__\#M?3^___!QQZ-C`N9>8):B8VP
M_O__BYVP_O__B<'!P04!RXG9P<$%C8P.F7F"6HG&B8V4_O__B<$A_O?1(=$#
ME?C^__\)\0.-E/[__XG>P<`>B964_O__B=HAQO?2(?H)\HNUE/[__P.]_/[_
M_\'#'HV4%IEY@EJ)E;#^__^+M;#^__^)RL'"!0'6B?+!P@6-E!>9>8):B<^)
ME93^__^)RB'?]](AP@GZB?<#E93^___!P1X#A0#___\ASXF%E/[__XGP]]`A
MV`GXB[V4_O__P<8>`YT$____C80'F7F"6HGWB86P_O__B=`QS\'`!3'7`X6P
M_O__C;P[H>O9;L'"'HG#P<,%`XT(____C1P?B=<Q]S''C;PYH>O9;HG9P<`>
MP<$%`[4,____C0P/B<<QUS'?C;P^H>O9;HG.P<,>P<8%`Y40____C30WB=\Q
MQS'/C;PZH>O9;HGRP<$>P<(%`X44____C107B<\QWS'WC;PXH>O9;HG0P<`%
M`<?!QAZ)\`.=&/___S'(,=#!PAZ-G`.AZ]ENB?C!P`4#C1S___^-!`.)TS'S
M,?N-G!FAZ]ENB<'!QQ[!P04!RXGY`[4@____,=$QP<'`'HVT#J'KV6Z)V<'!
M!0.5)/___XT,#HG&,?XQWHVT,J'KV6Z)RL'#'L'"!0'6B=H#O2C___\QPC'*
MP<$>C;P7H>O9;HGRP<(%`X4L____C107B<\QWS'WC;PXH>O9;HG0P<`%`<?!
MQAZ)\`.=,/___S'(,=#!PAZ-G`.AZ]ENB?C!P`4#C33___^-!`.)TS'S,?N-
MG!FAZ]ENB<'!QQ[!P04!RXGY`[4X____,=$QP<'`'HVT#J'KV6Z)V<'!!0.5
M//___XT,#HG&,?XQWHVT,J'KV6Z)RL'#'L'"!0'6B=H#O4#___\QPC'*P<$>
MC;P7H>O9;HGRP<(%`X5$____C107B<\QWS'WC;PXH>O9;HG0P<`%`<?!QAZ)
M\`.=2/___S'(,=#!PAZ-G`.AZ]ENB?C!P`4#C4S___^-!`.)TS'S,?N-G!FA
MZ]ENB<'!QQ[!P06-#`N)^P.U4/___S'3,<,#E53___^-M!ZAZ]ENB<O!P![!
MPP6-'!Z)QHF5E/[__PG^B<(A^B'."=:+E93^__\#O5C____!P1Z-M#+<O!N/
MB=K!P@6-%!:)SHF]E/[__PG&B<\AQR'>"?Z+O93^__\#A5S____!PQZ-M#?<
MO!N/B=^)A93^__\)SXG8B;6P_O__B=;!Q@4#M;#^__\AUR'("<>+A93^__\#
MC6#____!PAZ-O#C<O!N/B?#!P`6-!`>)UXF-E/[__PG?B=$AV2'W"<^+C93^
M__\#G63____!QAZ-O#G<O!N/B<'!P06-#`^)]XF=E/[__PG7B?,ATR''"=^+
MG93^__\#E6C____!P!Z-O#O<O!N/B<O!PP6-'!^)QXF5E/[__PGWB<(A\B'/
M"=>+E93^__\#M6S____!P1Z-O#K<O!N/B=K!P@6-%!>)SXFUE/[__PG'B<XA
MWR'&"?>+M93^___!PQZ-O#[<O!N/B=;!Q@4#A7#___^--#>)WPG/B864_O__
MB=@AUR'("<>+A93^__\#C73____!PAZ-O#C<O!N/B?#!P`6-!`>)UXF-E/[_
M_PG?B=$AV2'W"<^+C93^__\#G7C____!QAZ-O#G<O!N/B<'!P06-#`^)]XF=
ME/[__PG7B?,ATR''"=^+G93^__\#E7S____!P!Z-O#O<O!N/B<O!PP6-'!^)
MQXF5E/[__PGWB<(A\B'/"=>+E93^__\#=8#!P1Z-O#K<O!N/B=K!P@6-%!>)
MSXFUE/[__PG'B<XAQB'?"?>+M93^__^-O#[<O!N/B=;!Q@4#183!PQZ--#>)
MWXF%E/[__PG/B=@AR"'7"<>+A93^__\#38C!PAZ-O#C<O!N/B?#!P`6-!`>)
MUXF-E/[__PG?B=$AV2'W"<^+C93^__\#78S!QAZ-O#G<O!N/B<'!P06-#`^)
M]XF=E/[__PG7B?,ATR''"=^+G93^__\#59#!P!Z-O#O<O!N/B<O!PP6-'!^)
MQXF5E/[__PGWB<(A\B'/"=>+E93^__\#=93!P1Z-O#K<O!N/B=K!P@6-%!>)
MSXFUE/[__PG'B<XAWR'&"?>+M93^__\#19C!PQZ-O#[<O!N/B=;!Q@6--#>)
MWXF%E/[__PG/B=@AR"'7"<>+A93^__\#39S!PAZ-O#C<O!N/B?#!P`6-!`>)
MUXF-E/[__PG?B=$AV2'W"<^+C93^__\#7:#!QAZ-O#G<O!N/B<'!P04!SXGQ
MB9V4_O__"=&)\R'3(<$)V8N=E/[__\'`'@-5I(V,"]R\&X^)PXF-L/[__XGY
M,?/!P04Q^P.-L/[__XV<&M;!8LK!QQZ)RL'"!0'3B?H#=:@QPC'*P<$>C;06
MUL%BRHG:P<(%`T6LC106B<XQ_C'>C;0PUL%BRHG0P<,>P<`%`<:)V`-]L#'(
M,=#!PAZ-O`?6P6+*B?#!P`4#3;2-!`>)US'?,?>-O#G6P6+*B<'!P07!QAX!
MSP-=N(GQ,=$QP8V<"];!8LJ)^<'`'L'!!0-5O(T,"XG#,?,Q^XV<&M;!8LJ)
MRL'''L'"!0'3B?H#=<`QPC'*P<$>C;06UL%BRHG:P<(%`T7$C106B<XQ_C'>
MC;0PUL%BRHG0P<,>P<`%`<:)V`-]R#'(,=#!PAZ-O`?6P6+*B?#!P`4#3<R-
M!`>)US'?,?>-O#G6P6+*B<'!P07!QAX!SP-=T(GQ,=$QP8V<"];!8LJ)^<'`
M'L'!!0-5U(T,"XG#,?,Q^XV<&M;!8LJ)RL'''L'"!0'3B?H#==@QPC'*P<$>
MC;06UL%BRHG:P<(%`T7<C106B<XQ_C'>C;0PUL%BRHG0P<,>P<`%`<:)V`-]
MX#'(,=#!PAZ-O`?6P6+*B?#!P`4#3>2-!`>)US'?,?>-O#G6P6+*B<'!QA[!
MP04#7>B-#`^)]S'7,<>-O#O6P6+*B<O!P![!PP4#5>R-'!^)QS'W,<^-O#K6
MP6+*B=K!P@4!UXN5J/[__P-5\,'!'HVT%M;!8LJ)RC'",=J-%!:)_L'&!0'R
MB[6L_O__P<,>B18#O:3^__\#G:#^__\#C9S^__\#A9C^__^)?@2)7@B)3@R)
M1A"!Q&`!``!;7E]=PXUV`%6)Y8/L.(E=](G#,<"%VXEU^(E]_(E5W'4.BUWT
MBW7XBWW\B>Q=PY"+%6!!!0B%THE5X'3E#[8#/#UT!(3`=4@QTHM%X(LP,<"%
M]G3-BWW@B5WDB=.-=@"+5>2)7"0(B30DB50D!.CU\/__A<!U!H`\'CUT*X/'
M!(LWA?9UVC'`ZYB-M@````")VH/"`0^V`CP]=`2$P'7R*=KKIHUT)@`K?>"+
M1=S!_P*).(U$'@'I9O___XVV`````(V_`````%6)Y8/L&(U5].@R____R<-5
MB>53B<.#[!2)V(U5].@=____A<!T*Y"+1?3!X`(#!6!!!0B-="8`@\`$BQ"%
MTHE0_'7TC57TB=CH\O[__X7`==:#Q!1;7<.0C;0F`````%6)Y5.#[!3'!"0`
M````Z'WP__^+`(D$).AC[?__B00DZ.OK__^+`(M8!,<$)`````#H6O#__XL`
MB00DZ$#M__^)!"3H>.S__P^V`(A#&,<$)`````#H-O#__XL`B00DZ!SM__^)
M!"3HI.O__XL`BU@$QP0D`````.@3\/__BP")!"3H^>S__XD$).A![/__BP`/
MMT`09B7_`6:)0QK'!"0`````Z.?O__^+`(D$).C-[/__B00DZ%7K__^+`(M8
M!,<$)`````#HQ.___XL`B00DZ*KL___'1"0(`````,=$)`0ES`0(B00DZ"+O
M__^)0QS'!"0`````Z)/O__^+`(D$).AY[/__B00DZ`'K__^+`(M8!,<$)```
M``#H<.___XL`B00DZ%;L__^)!"3H;NO__XL`B4,@QP0D`````.A-[___BP")
M!"3H,^S__XD$).B[ZO__BP"+6`3'!"0`````Z"KO__^+`(D$).@0[/__B00D
MZ"CN__\QTHL`A<!T(\<$)`````#H!.___XL`B00DZ.KK__^)!"3H`N[__XL`
MBU!LB5,DQP0D`````.C>[O__BP")!"3HQ.O__XD$).A,ZO__BP"+0`3'0"@`
M````QP0D`````.BT[O__BP")!"3HFNO__XD$).@BZO__BP"+0`3'0"P`````
MQP0D`````.B*[O__BP")!"3H<.O__XD$).CXZ?__BP"+6`3'!"0`````Z&?N
M__^+`(D$).A-Z___B00DZ"7N__^+`(E#,(/$%%M=PXUV`(V\)P````!5B>57
MB<=64X'LG````(7`=`6`.`!U$8'$G````%M>7UW#C;8`````B00DZ)#K__^%
MP(G&=.%FD(DT).CPZ___A<`/A-````"-6!,/MA5)R@0(#[9`$SG0=0X/MA5*
MR@0(.%,!=-)FD`^V%4C*!`@YT`^$P0```(D\).CAZ___B1PDB46`Z-;K__^+
M58"-1`("B00DZ&?L__^)7"04B7PD$,=$)`Q+R@0(QT0D"/_____'1"0$`0``
M`(E%A(D$).@,[?__BU6$C46(B40D",<$)`,```")5"0$Z(+I__^#^/]T#XM%
MF"4`\```/0!```!T;HM%A(D$).ASZ___BU6$B10DZ&CJ__^)-"3H(.O__X7`
M#X4P____B30DZ*#K__^)/"3H".S__X'$G````%M>7UW#D(UT)@`/M@5)R@0(
M.$,!#X4O____#[852LH$"#A3`@^$X/[__^D:____C78`BT6$Z)C^___KDXVV
M`````%6)Y5:)QE,QVX/L$,<$)`````#HN.S__XL`B00DZ)[I__^)!"3HQNO_
M_XET)`3'!"0#````B40D".CBZ?__A<!T#H/$$(G86UY=PY"-="8`QP0D````
M`.AT[/__BP")!"3H6NG__XD$).B"Z___BT`0)0#P```]`$```'0MQP0D````
M`.A'[/__BP")!"3H+>G__XD$).A5Z___BT`0)0#P```]`*```'68B30D,=O'
M1"0$`@```.ATZ?__A<`/E,.#Q!")V%M>7<.-M@````!5B>575HG&4S'`@^P\
MB=.`.CT/E,`!PXD<).@!ZO__C57DB474B?#H)/K__X7`B<=T+HD$).CFZ?__
M,=(Y1=0/AWT!``"-=@`/M@03B`07@\(!A,!U\C'`@\0\6UY?7<.+%6!!!0@Q
M_[@(````BPJ%R706D(UT)@"#QP&+!+J%P'7VC02]"````(L-D$$%"(7)#X39
M````B40D!(D4).A=Y___B<&%R:-@004(N/____]TI8T$O0````")1=#'1+D$
M`````(E]Y`^V!CP]#X3]````A,`/A/4```")\.L%D(32=`N#P`$/MA"`^CUU
M\8M5U"GPBWW0`SU@004(C40"`HD$).BWZ?__B<*%THD'N/____\/A#[___^+
M5>2A8$$%"(L$D`^V%H32B!!T'H#Z/709@\8!ZP6`^CUT#P^V%H/``8/&`832
MB!!U[,8`/3'2C;0F``````^V#!.(3!`!@\(!A,EU\>GJ_O__C70F`(E5S,<%
MD$$%"`$```")!"3H.^G__XM5S(G!N/____^%R0^$P?[__XT$O0````")#"2)
M3<R)1=")1"0(B50D!.B,Z?__BTW,B0U@004(Z?O^__^+1>3!X`*)1=#I^/[_
M_XGPZ1C___^)]HV\)P````!5B>6![$@0``")??R-O>3O__^)7?2)PXEU^&6A
M%````(E%Y#'`B974[___QT0D"/\/``")?"0$QP0D4<H$".@-Z?__A<!^<8"\
M!>/O__\`B<9T78ET)`C'1"0$+P```(D\).A9Z?__A<!T3<<$)`````#HJ>G_
M_XL`B00DZ(_F__^)="0,B7PD"(E<)`2)!"3HV^?__XM%Y&4S!10```!U18M=
M](MU^(M]_(GL7<-FD(/N`76>C78`QP0D`````.A<Z?__BP")!"3H0N;__XN5
MU.___XE<)`2)5"0(B00DZ/SE___KK^@5Z/__D(UT)@!5B>6#[!C'!"0`````
MZ![I__^+`(D$).@$YO__QT0D#&#*!`C'1"0(T)8$",=$)`1JR@0(B00DZ-3H
M___)PV:058GE@^PHQP0D`````.C>Z/__BP")!"3HQ.7__XD$).B<____QP0D
M`````.C`Z/__BP")!"3HIN7__\=$)!0`````QT0D$"7,!`C'1"0,)<P$",=$
M)`B@P00(QT0D!(;*!`B)!"3H5N;__\G#C70F`%6)Y8'L2"```(E=](V=X^__
M_XEU^#'V9:$4````B47D,<")??SHYN/__\=$)!1<R@0(QT0D#)O*!`C'1"0(
M`1```,=$)`0!````B1PDB40D$.BZY___A<!Y'HM5Y&4S%10```")\'57BUWT
MBW7XBWW\B>Q=PXUV`(V]XM___XD<),=$)`@`$```B7PD!.@>Y___A<")PWC"
MC4`!B00DZ)WF__^%P(G&=+&)7"0(B7PD!(D$).C'Y?__Q@0>`.N;Z)SF__^-
MM@````"-OP````!5B>6#[`C)Z23___^-="8`58GE5U93@>Q,$```BUT(9:$4
M````B47D,<"XI\H$"(M]#.B)]O__QT0D!"\```")'"2)A=3O___HL^/__X7`
M="F)VKBPR@0(Z%/[__^+5>1E,Q44````B=@/A84!``"!Q$P0``!;7E]=PXD<
M).A.Y?__B3PDQT0D!+W*!`B)QN@<YO__A<")QW2W@\8!B;70[___C;7D[___
MC;0F`````(`_`+A)R@0(#T3XBX74[___A<!T&HN5U.___XE\)`2)%"3H^>;_
M_X7`#X3#````B3PDZ.GD__^`?`?_+W409I"#Z`&`?`?_+\8$!P!T\@.%T.__
M_SW_#P``#X]"____B5PD&,=$)!2_R@0(B7PD$,=$)`S;RP0(QT0D"``0``#'
M1"0$`0```(DT).@!YO__QP0D`````.AEYO__BP")!"3H2^/__XD$).ASY?__
MB70D!,<$)`,```")1"0(Z%_B__^%P'4MQP0D`````.@OYO__BP")!"3H%>/_
M_XD$).@]Y?__BT`0)0#P```]`(```'0CQT0D!+W*!`C'!"0`````Z/KD__^%
MP(G'#X7P_O__Z8S^___'1"0$`0```(DT).@[X___A<!UR8GRN+#*!`CHR_G_
M_XDT).@#YO__B</I:?[__^B7Y/__C;0F`````%6)Y8M%"`^V"(3)=!.-4`&`
M^2\/M@H/1,*#P@&$R77P7<.-M"8`````C;PG`````%6)Y5.#[!2+70B%VW0J
M@#L`="6)'"3HA>/__XU$`_\YPW(,ZS^-=@"#Z`$YPW,U@#@O=/3K)V:0QP0D
M`@```.C\X___A<!T!6;'`"X`@\046UW#D(UT)@"`."]T!X/H`3G#<O0YV'48
M@#@O=%O'10B_R@0(@\046UWI0N7__V:0@^@!.<-S!8`X+W3TB<(QP"G:C4H"
M@?D`$```=["#P@''1"0,`!```(E4)`B)7"0$QP0DH$$%".B$X/__N*!!!0CK
MBI"-="8`QP0D`@```.ALX___B<(QP(72#X1M____9L<"+@")T.EA____C70F
M`%6)Y5=6@^PP9:$4````B47T,<"A-,P$"(E%TJ$XS`0(B476H3S,!`B)1=JA
M0,P$"(E%WJ%$S`0(B47BH4C,!`B)1>:A3,P$"(E%ZJ%0S`0(B47N#[<%5,P$
M"&:)1?*XP<H$".A(\___N,K*!`CH/O/__[C2R@0(Z#3S__^XV\H$".@J\___
MN.+*!`CH(//__[CRR@0(Z!;S__^XI\H$".@,\___N/[*!`CH`O/__[@(RP0(
MZ/CR__^X$LL$".CN\O__N+#*!`CHY/+__[@<RP0(Z-KR__^X)<L$".C0\O__
MN##+!`CHMO+__X7`=`R)PK@(RP0(Z);W__^X0<L$".B<\O__A<!T#(G"N%/+
M!`CH?/?__[A>RP0(Z(+R__^%P'0NB<*XI\H$".AB]___NHK+!`BXXLH$".A3
M]___BT7T93,%%````'5'@\0P7E]=P[ANRP0(Z$;R__^%P'02B<*X_LH$".@F
M]___Z\*-="8`C77COW_+!`BY"@```/.F=:V-5>VX_LH$".@"]___ZY[HV^'_
M_XUT)@"-O"<`````58GE@^P(H4Q!!0B#^/]T",G#C;8`````N/[*!`CHWO'_
M_XG",<"%TG0/#[82A-)T"#'`@/HP#Y7`HTQ!!0C)PU6)Y8/L&.@%X?__B00D
MZ-W@__^)PC'`A=)T`HL"R<.058GE5U93NY;+!`B#[%R+?0C'1="6RP0(C774
MQT74C,L$",=%V)G+!`C'1=R/RP0(QT7@E,L$",=%Y"7,!`CK'8E\)`2)!"2)
M1<3H\>#__X7`=#6+'H/&!(`[`'0CB=CH//'__X7`=`6`.`!UTXG8B?KH&O;_
M_XL>@\8$@#L`==V#Q%Q;7E]=PXD\).@@X/__BU7$B10DB47`Z!+@__^+3<"-
M1`$"B00DZ*/@__^+5<3'1"04O<H$"(E\)!#'1"0,V\L$"(E4)!C'1"0(____
M_\=$)`0!````B00DB47`Z#WA__^+3<")V(G*Z*'U___I7____XVV`````(V_
M`````%6)Y5=64X'L/($``(M%"&6+%10```")5>0QTL>%*'___[++!`C'A2Q_
M__^ZRP0(B87X?O__N*?*!`C'A3!___])R@0(QX4T?___)<P$",>%$'___U/+
M!`C'A11___],RP0(QX48?___O\L$",>%''___[7+!`C'A2!____'RP0(QX4D
M?___)<P$",>%.'___Z;+!`C'A3Q____+RP0(QX5`?___)<P$".CS[___A<!T
M"8`X``^%)@,``(VV`````.@;_O__A<")QP^$.0,```^V'X3;="+H5=[__XGZ
MC78`BP@/OMOV!%D(=0/&`E^#P@$/MAJ$VW7HNP$```"X4\L$".L7C70F`(N$
MG1!___^#PP&`.``/A&T"``#H@.___X7`B<9TXNB5\___A<!TV8DT).B9X/__
MA<!TS8G&B30DZ&O>__^)/"2)P^AAWO__C90#!`0``(D4)(F5['[__^CLWO__
MBY7L?O__B10DB<.)A?1^___HUM[__XE\)!S'1"08U,L$",=$)!2_R@0(B70D
M$,=$)`S9RP0(B87\?O__QT0D"/_____'1"0$`0```(D$).AHW___BXW\?O__
MQT0D!.T!``")#"3H8MO__[B/RP0(Z,CN__^%P`^$:`(``(D$).CHW___B[WX
M?O__B40D!(L'B00DZ/3W__^%P(F%`'___P^$/@(``(N5`'___XD4).B8W?__
M@_@#?C.+C0!___^_XLL$"(UT`?RY!0```/.F=1N#^`0/A(H&``"+O0!___^`
M?`?[+P^$>08``)#H2_S__X7`=22+E0!____'1"0$`````(D4).CAWO__A<")
MA?A^__\/A>,!``"ZBLL$"+C^R@0(Z`3S__\Q]NB-VO__BXW\?O__QT0D'"7,
M!`C'1"04O\H$",=$)`P`S`0(B4PD$,=$)`C_____B40D&,=$)`0!````B1PD
MZ$_>__^+O?Q^___K58VT)@````#H&]K__X,X$759Z#':__^#Q@''1"0@)<P$
M"(ET)!S'1"04O\H$"(E\)!#'1"0,#LP$"(E$)!C'1"0(_____\=$)`0!````
MB1PDZ/+=___'1"0$[0$``(D<).CRV?__@_C_=)V+O?Q^__^)/"3H;]O__XG:
MN*?*!`CH,_+__XD<).B;^___BU7D93,5%````(N%]'[__P^%C08``('$/($`
M`%M>7UW#9I"+M2A___^[`0```(`^`'47ZS^-M@````"+M)TH?___@\,!@#X`
M="J)\.@*\?__A<!TYHDT).@.WO__A<`/A7']__^+M)TH?___@\,!@#X`==8Q
M]NE=_?__B00DB87L?O__Z!+[__^+A>Q^__^)!"3HU-W__XF%]'[__^E>____
MD+L!````N*;+!`CK%XUT)@"+A)TX?___@\,!@#@`#X3M!```Z'#L__^%P'3D
MB00DZ)3=__^%P'38B<?IB/S__Y"+A?A^__^+`(F%`'___^FO_?__D(UT)@#'
M1"0,`@```,=$)`3N____QT0D"/____^)!"3H@-G__XN]^'[__XV-1'___\=$
M)`@&````B4PD!(D\).CPV?__@+U$?___`'4-@+U%?___0P^$NP0``(N]^'[_
M_\=$)`P`````QT0D!`````#'1"0(`````(D\).@DV?__C85@____QX5$____
M`2-%9\>%2/___XFKS>_'A4S____^W+J8QX50____=E0R$,>%5/____#ATL/'
MA5C___\`````QX5<____`````,=%H`````")A01___^)G?!^__^0C70F`(N]
M^'[__XV-1'___\=$)`@`@```B4PD!(D\).@PV?__A<`/CH@!``"+C5C___^)
MQXT4P3G*#Y+!#[;)B958____B<(!C5S____!ZAT!E5S___^+5:"-C41___^)
MC0!___^%TG13NT`````ITSG8#T[8C85@____C100B5PD"(E,)`2)%"3HQMG_
M_XM%H`'8@_A`B46@#X5E____C85$?___*=\!V(F%`'___XV%1/___^C:W/__
M9I"#_S\/CL(```"+G0!___^)_HVT)@````"+`X/N0(F%8/___XM#!(F%9/__
M_XM#"(F%:/___XM##(F%;/___XM#$(F%</___XM#%(F%=/___XM#&(F%>/__
M_XM#'(F%?/___XM#((E%@(M#)(E%A(M#*(E%B(M#+(E%C(M#,(E%D(M#-(E%
ME(M#.(E%F(M#/(/#0(E%G(V%1/___^@XW/__@_X_#X]O____@^]`BXT`?___
MB?C!Z`:)PL'B!HU4"D#!X`:)E0!___\IQXN%`'___XV58/___\=$)`Q$````
MB7PD"(D4)(E$)`3HB=?__XE]H.E1_O__D(N=\'[__XD\).@BV?__B[58____
MBY5<____B?#!Z`.#X#_&A`5@____@(/``8/X.`^/_`$``+DX````C;U@____
M*<&-!`>)E>Q^__^)3"0(QT0D!`````")!"3H\-;__XN5['[__XG0P>@8B$68
MB=#!Z!"(19F)T,'H"(A%FHGPP>@8B$6<B?#!Z!"(19V)\,'H"(A%GHGP,?:(
M19^-A43___^(59N-?:?H,MO__XN51/___XG1P>D8B<B(3=")T<'I$(A-T8G1
MB%73BY5(____P>D(B$W2B='!Z1B(3=2)T<'I$(A-U8G1B%77BY5,____P>D(
MB$W6B='!Z1B(3=B)T<'I$(A-V8G1B%7;BY50____P>D(B$W:B='!Z1B(3=R)
MT<'I$(A-W8G1B%7?BY54____P>D(B$W>B='!Z1B(3>")T<'I$(A-X8G1P>D(
MB$WBB%7CZP:0#[9$-=`/ML")1"00C01W@\8!QT0D#/O+!`C'1"0(_____\=$
M)`0!````B00DZ*;8__^#_A1UR8N5_'[__\9%SP#'1"0<)<P$"(E\)!C'1"04
MO\H$"(E4)!#'1"0,[,L$",=$)`C_____QT0D!`$```")'"3H7]C__^E]^O__
M9I"+A?A^__^+4`2%T@^$=_G__XD4)(F5['[__^C)UO__BY7L?O__@_@##X9:
M^?__C70"_+_GRP0(N04```#SI@]%E0!___^)E0!____I./G__[^KRP0(Z=;W
M__^-O6#___^Y0````"G!C00'B4PD"(F5['[__\=$)`0`````B00DZ/34__^-
MA43____H>=G__XN]!'___[D.````,<#SJXN5['[__^GE_?__@+U&?___00^%
M./O__X"]1W___T,/A2O[__^`O4A___](#X4>^___@+U)?___10^%$?O__\=$
M)`P"````QT0D!,;____'1"0(_____XD\).@[U/__C85$?___QT0D""D```")
M1"0$B3PDZ+'4__^+C?Q^__^-E41____'1"0<)<P$"(E4)!C'1"04O\H$"(E,
M)!#IF?[__^ACUO__C78`58GE5U93@^PLQP0D`````.AKU___BP")!"3H4=3_
M_XD$).C)U/__Q@`!N.+*!`CH7.;__X7`=`F`.#$/A`\#``#HJO+__\<$)```
M``#H+M?__XL`B00DZ!34___'1"0,"P```,=$)`@!````QT0D!!_,!`B)!"3H
MI-/__X7`#X3<````BT`,,?:+0!B)1>2AB$$%"(/X`0^.N````+L!````ZS.-
M="8`BT<,BQ6$004(BQ2:B40D!(D4).C@UO__A<`/A8@```"AB$$%"(/#`8/&
M`3G8?G['!"0`````Z)W6__^+`(D$).B#T___BU7DQT0D#`````")="0(B50D
M!(D$).CHU/__A<!T1(LX]D<)!'64QP0D`````.A@UO__BP")!"3H1M/__\=$
M)`P"````QT0D"`````")?"0$B00DZ*K6___I8/___Y"-="8`H8A!!0B-4/\Y
M\@^$@`$``,<$)`````#H%-;__XL`B00DZ/K2___'1"0,!0```,=$)`@!````
MQT0D!"3,!`B)!"3HBM+__X7`B<-T/HM`#(LPQP0D`````.C3U?__BP")!"3H
MN=+__\=$)`@FS`0(B70D!(D$).AUTO__BT,,BQCV0PI`#X5.`0``QP0D````
M`.B:U?__BP")!"3H@-+__\=$)`P%````QT0D"`$```#'1"0$+LL$"(D$).@0
MTO__A<")PW0_N+#*!`CH<.3__X7`B<8/A#X!``"+0PR+.,<$)`````#H1=7_
M_XL`B00DZ"O2__^)="0(B7PD!(D$).CKT?__QP0D`````.@?U?__BP")!"3H
M!=+__XD$).A]TO__Q@``QP0D`````.C^U/__BP")!"3HY-'__XD$).@<U?__
MQP``````N*?*!`CH[./__X7`HXQ!!0@/A.<```#'1"0$[0$``(D$).A?T/__
M@_@1=!"%P'0,@_C_C78`#X4G`0``@\0L6UY?7<-FD(/X`0^.=_[__[L!````
M9I#'!"0`````@\,!Z('4__^+`(D$).AGT?__BU7DB50D!(D$).CXT/__.1V(
M004(?]#I._[__XUV`,<$)`````#H3-3__XL`B00DZ#+1__^)7"0$B00DZ`;3
M___IB_[__Y"`>`$`#X3L_/__C;8`````Z=S\__^-=@"AA$$%"(LXBT,,BS#'
M!"0`````Z`#4__^+`(D$).CFT/__B?J)\.C-Z?__Z;W^__^AA$$%"(D$).A+
M\O__BSV$004(HXQ!!0B+0PR+,/9&"00/A)8```"+1@R)?"0$B00DZ,+1__^)
MQHM##(L8]D,)!'1&BT,,B40D"*&$004(B70D#(L`QP0D6,P$"(E$)`3HT]+_
M_XE$)`RAC$$%"(E$)`BAA$$%"(L`QP0DB,P$"(E$)`3HK]+__\<$)`````#H
M4]/__XL`B00DZ#G0___'1"0,`@```,=$)`@`````B5PD!(D$).B=T___ZXG'
M!"0`````Z!_3__^+`(D$).@%T/__QT0D#`(```#'1"0(`````(ET)`2)!"3H
M:=/__^DV____C70F`%6)Y593@^P0BW4(B30DZ%WM__\/MA")PX32=0[K'6:0
M@\`!#[80A-)T$8#Z+W7Q@\`!#[80B<.$TG7OZ,#O__^%P'0=A?9T&8`^`'04
MQT0D!-3+!`B)'"3H0]'__SG8=`>#Q!!;7EW#@\00B?!;7EWI.^3__XUT)@"-
MO"<`````58GE@^P8QP0D`````.A>TO__BP")!"3H1,___\=$)`3_____B00D
MZ(3/___'!"0`````Z#C2__^+`(D$).@>S___QT0D"`````#'1"0$D*@$"(D$
M).AVTO__R<.-="8`58GE@^3P5E.#[#B-11")1"0(C44,B40D!(U%"(D$).C<
MT?__QT0D"`"5!`C'1"0$`)4$",<$)."6!`CHX`$``,<$)`````#HY,[__X`X
M`'4[Z,K.__^%P*.`004(#X2Q`0``B00DZ(7/___'!"0`````Z)G1__^+`(D$
M).A_SO__B00DZ.?0___&``#'!"0`````Z'C1__^+`(D$).A>SO__B00DZ';1
M__^`"`+'!"0`````Z%?1__^+`(D$).@]SO__B00DZ%71__\QR8`(`8M%"(E,
M)"R#P`6)1"0HWVPD*-@%V,P$"-T%X,P$"-G)W^G=V`^'!@$``,'@`HD$).A[
MT/__BW4,HX1!!0B+%L=`!"O,!`C'0`@`S00(QT`,+LP$"(D0BUT(QP6(004(
M!````(/[`7X6N@$```"-=@"+#):)3)`,@\(!.=IU\H/#`\<$F`````")1"0,
MH8!!!0B)7"0(QT0D$`````#'1"0$,+`$"(D$).ACS/__A<")PW0]H8!!!0B)
M!"3H(,___[CRR@0(Z(;?__^%P'0ZH8!!!0B)!"3H%<S__^CPS?__@\0XB=A;
M7HGL7<.0C70F`*&`004(B00DZ,/,__^)P^NRC;0F`````*&,004(A<!T"HD$
M).@W_?__Z[.XI\H$".@KW___A<"CC$$%"'2@Z^''1"0$9$$%",<$)*3*!`CH
M3,___\<$)`$```#H0-#__U6)Y5/H,@```('#NW8``(/L$(N#5`$``(E$)`R+
M11")1"0(BT4,B40D!(M%"(D$).@;S/__@\006UW#BQPDPY!5B>575E/H\/__
M_X'#>78``(/L'.C'RO__C;L0____C8,0____*<?!_P*%_W0D,?:+11")1"0(
MBT4,B40D!(M%"(D$)/^4LQ#___^#Q@$Y_G+>@\0<6UY?7<.-M@````!5B>5=
MPY"0D)"0D)"0D)"058GE4X/L!*$$/P4(@_C_=!.[!#\%"&:0@^L$_]"+`X/X
M_W7T@\0$6UW#D)!5B>53@^P$Z`````!;@</<=0``Z*S/__]96\G#````````
M`````````````````````````P````$``@`N+@`E<R\E<P`O<')O8R]S96QF
M+V5X90!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]0
M4D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"
M54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$
M14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0051(`$19
M3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`$,Z7%1%35``+W1M<`!414U0
M1$E2`%1-4`!54T523D%-10!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S
M8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E
M<P!!4D=6`!@`<&5R;``M90`M+0````!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(``````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B
M;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP
M;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@
M)6DN"@````````````````"`____ST%P87(N<&P`````````````````````
M```C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M
M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C
M<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE
M("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M
M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U
M<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y
M:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@
M=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@
M("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES
M86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N
M9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@
M8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL
M97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@
M("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U
M<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@
M8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I
M;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L
M"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@
M("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE
M.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES
M=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N
M("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X
M:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@
M>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@
M)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P
M?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L
M971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I
M;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*
M7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD
M(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O
M<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D
M871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@
M;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@
M<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L
M87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&
M2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&
M2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@
M(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R
M>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@
M(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI
M;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@
M)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@
M("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@
M)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@
M("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U
M;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]
M?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2![
M"B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I
M"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D
M8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL
M96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@
M("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@
M("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L
M"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@
M("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@
M("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N
M86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@
M("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES
M("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S
M("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L
M87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R
M971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL
M96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F
M:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*
M("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H
M)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U
M="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@
M("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W
M(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE
M('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E
M<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ
M2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T
M<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q
M=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@
M:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=]
M(#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE
M<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I
M('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X
M96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@
M9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE
M;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE
M("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G
M=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R
M+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q
M=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L
M;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S
M:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@
M:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO
M;G,@+2UR975S92!04D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE
M(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N
M>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S
M970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@
M("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@
M("`@('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W
M:&EL92`H0$%21U8I('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF
M("@D,2!E<2`G22<I('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I
M;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G32<I('L*("`@("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@
M("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@
M("`@("`@("1O=70@/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@
M)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G0B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@
M("`@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@
M;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@
M("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@
M("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@
M("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E(%!!
M4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X:70[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.
M0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD
M96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD
M;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H
M:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@
M("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@
M("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*
M"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@
M("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E
M;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<
M-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E
M*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U
M;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T
M95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F
M:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O
M<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R
M(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*
M("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@
M("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@
M/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M
M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@
M("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@
M("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R
M*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N
M9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R
M97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E
M<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@
M("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!]
M(&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@
M>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@
M("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@
M("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T
M(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N
M+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL
M:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED
M(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@
M("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U
M;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A
M:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O
M7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES
M("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*
M("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R
M="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE
M*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@
M("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I
M*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L
M("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO
M*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q
M(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S
M=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@
M("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@
M("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF
M("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F
M:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@
M(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*
M("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@
M("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O
M*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@
M("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N
M<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET
M=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,
M12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H
M"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@
M("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE
M(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&
M:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T
M.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@
M(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E
M<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B
M8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@
M("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F
M:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N
M86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*
M("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT
M*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U
M-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P
M87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G
M;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@
M:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@
M("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@
M("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A
M.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0
M?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@
M("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U[
M"B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@
M("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D
M"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE
M(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@
M("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H
M<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@
M("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP
M=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*
M?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W
M('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A
M=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN
M84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R
M:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*
M("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@
M("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@
M(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*
M("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@
M(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@
M("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V
M>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E
M=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R
M('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@
M;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!
M4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A
M<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@
M/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@
M;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O
M97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S
M97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE
M(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#
M;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S
M=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@
M("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@
M("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@
M("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@
M("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@
M("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I
M9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U
M;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@
M("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M
M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H
M)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%
M3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D
M:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C
M*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA
M;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL
M96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@
M?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE
M*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@
M<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@
M:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?
M<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*
M"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@
M("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@
M("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#
M;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA
M<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@
M("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M
M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C
M(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@
M("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*
M("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D
M96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`]
M(")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@
M*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,
M14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C
M;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@
M("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*
M("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*
M?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4
M:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E
M(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE
M.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,@H*7U]%3D1?7PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#_____`````/____\`````
M``````$````!`````0```+("```!`````0,```P```!0E`0(#0````S*!`CU
M_O]OC($$"`4````TB@0(!@```.2"!`@*````\@4```L````0````%0``````
M```#````]#\%"`(```"(`@``%````!$````7````R)$$"!$```"PD00($@``
M`!@````3````"````/[__V\0D00(____;P(```#P__]O)I`$"```````````
M```````````````````````````````````````````````````````````8
M/P4(``````````"6E`0(II0$"+:4!`C&E`0(UI0$".:4!`CVE`0(!I4$"!:5
M!`@FE00(-I4$"$:5!`A6E00(9I4$"':5!`B&E00(EI4$"*:5!`BVE00(QI4$
M"-:5!`CFE00(]I4$"`:6!`@6E@0()I8$"#:6!`A&E@0(5I8$"&:6!`AVE@0(
MAI8$"):6!`BFE@0(MI8$",:6!`C6E@0(YI8$"/:6!`@&EP0(%I<$"":7!`@V
MEP0(1I<$"%:7!`AFEP0(=I<$"(:7!`B6EP0(II<$"+:7!`C&EP0(UI<$".:7
M!`CVEP0(!I@$"!:8!`@FF`0(-I@$"$:8!`A6F`0(9I@$"':8!`B&F`0(EI@$
M"*:8!`BVF`0(QI@$"-:8!`CFF`0(]I@$"`:9!`@6F00()ID$"#:9!`A&F00(
M5ID$"&:9!`AVF00(AID$"):9!`@``````````/_____HS`0(Z5L``$=#0SH@
M*%5B=6YT=2],:6YA<F\@-"XU+C(M,75B=6YT=3(I(#0N-2XR```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`
M+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````
M```````````````````````````````````````+`````0````(````T@00(
M-`$``!,```````````````$`````````$P````<````"````2($$"$@!```@
M```````````````$`````````"$````'`````@```&B!!`AH`0``)```````
M````````!``````````T````]O__;P(```",@00(C`$``%@!```%````````
M``0````$````/@````L````"````Y(($".0"``!0!P``!@````$````$````
M$````$8````#`````@```#2*!`@T"@``\@4``````````````0````````!.
M````____;P(````FD`0()A```.H````%``````````(````"````6P```/[_
M_V\"````$)$$"!`1``"@````!@````(````$`````````&H````)`````@``
M`+"1!`BP$0``&`````4`````````!`````@```!S````"0````(```#(D00(
MR!$``(@"```%````#`````0````(````?`````$````&````4)0$"%`4```P
M```````````````$`````````'<````!````!@```("4!`B`%```(`4`````
M````````!`````0```""`````0````8```"@F00(H!D``&PP````````````
M`!``````````B`````$````&````#,H$"`Q*```<```````````````$````
M`````(X````!`````@```$#*!`A`2@``JEX`````````````(`````````"6
M`````0````(```#L*`4([*@```0```````````````0`````````H`````$`
M```#````!#\%"`2O```(```````````````$`````````*<````!`````P``
M``P_!0@,KP``"```````````````!`````````"N`````0````,````4/P4(
M%*\```0```````````````0`````````LP````8````#````&#\%"!BO``#8
M````!@`````````$````"````+P````!`````P```/`_!0CPKP``!```````
M````````!`````0```#!`````0````,```#T/P4(]*\``%`!````````````
M``0````$````R@````$````#````1$$%"$2Q```4```````````````$````
M`````-`````(`````P```&!!!0A8L0``0!``````````````(`````````#5
M`````0```#``````````6+$``"H```````````````$````!`````0````,`
B`````````````(*Q``#>```````````````!````````````
